NodeHandle

Struct NodeHandle 

pub struct NodeHandle { /* private fields */ }
Handle to a node for ergonomic port references

Implementations

Source

impl NodeHandle

pub fn id(&self) -> NodeId

pub fn from_module(id: NodeId, module: &dyn GraphModule) -> Self

Create a NodeHandle from a NodeId and module reference

pub fn output(&self, name: &str) -> Result<PortRef, PatchError>

Reference an output port by name, returning an error if it does not exist.

Prefer this over the panicking out when the port name comes from untrusted or dynamic input (e.g. deserializing a patch). The error lists the valid output ports for this module.

pub fn input(&self, name: &str) -> Result<PortRef, PatchError>

Reference an input port by name, returning an error if it does not exist.

The fallible companion to in_; see output.

pub fn out(&self, name: &str) -> PortRef

Reference an output port by name (panicking convenience).

Panics with a message listing the valid output ports if name is unknown. For a non-panicking version use output.

pub fn in_(&self, name: &str) -> PortRef

Reference an input port by name (panicking convenience).

Panics with a message listing the valid input ports if name is unknown. For a non-panicking version use input.

pub fn input_names(&self) -> Vec<&str>

List the names of this module’s input ports (in spec order).

pub fn output_names(&self) -> Vec<&str>

List the names of this module’s output ports (in spec order).

pub fn spec(&self) -> &PortSpec

Get the port specification