pub type NodeId = DefaultKey;Expand description
Unique identifier for a node in the patch graph
Aliased Type
pub struct NodeId(/* private fields */);pub type NodeId = DefaultKey;Unique identifier for a node in the patch graph
pub struct NodeId(/* private fields */);