pub trait ModuleIntrospection: GraphModule {
// Provided methods
fn param_infos(&self) -> Vec<ParamInfo> { ... }
fn get_param_info(&self, id: &str) -> Option<ParamInfo> { ... }
fn set_param_by_id(&mut self, _id: &str, _value: f64) -> bool { ... }
}Available on crate feature
alloc only.Expand description
Trait for modules to expose their parameters to UIs
This trait extends GraphModule to provide parameter metadata
that UIs can use to automatically generate appropriate controls.
Provided Methods
Sourcefn param_infos(&self) -> Vec<ParamInfo>
fn param_infos(&self) -> Vec<ParamInfo>
Get all parameter descriptors for this module
Returns a list of ParamInfo describing each controllable parameter.
The order should be consistent and reflect a logical grouping.
Sourcefn get_param_info(&self, id: &str) -> Option<ParamInfo>
fn get_param_info(&self, id: &str) -> Option<ParamInfo>
Get a specific parameter by its ID
Sourcefn set_param_by_id(&mut self, _id: &str, _value: f64) -> bool
fn set_param_by_id(&mut self, _id: &str, _value: f64) -> bool
Set a parameter value by its ID
Returns true if the parameter was found and set, false otherwise.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".