ExternalInput

Struct ExternalInput 

pub struct ExternalInput { /* private fields */ }
Available on crate feature alloc only.
External input source - reads from an atomic value set by another thread

This module allows values from external sources (MIDI, OSC, GUI, etc.) to be brought into the patch graph in a lock-free manner.

Implementations

Source

impl ExternalInput

pub fn new(value: Arc<AtomicF64>, kind: SignalKind) -> Self

Create a new external input with the specified signal kind

pub fn voct(value: Arc<AtomicF64>) -> Self

Create for pitch CV (V/Oct)

pub fn gate(value: Arc<AtomicF64>) -> Self

Create for gate signals

pub fn cv(value: Arc<AtomicF64>) -> Self

Create for unipolar CV

pub fn cv_bipolar(value: Arc<AtomicF64>) -> Self

Create for bipolar CV

pub fn trigger(value: Arc<AtomicF64>) -> Self

Create for trigger signals

pub fn audio(value: Arc<AtomicF64>) -> Self

Create for audio input

pub fn value_ref(&self) -> &Arc<AtomicF64>

Get a reference to the underlying atomic value