pub struct BernoulliGate { /* private fields */ }Expand description
Bernoulli Gate
A probabilistic gate router. On each trigger, randomly routes the signal to one of two outputs based on a probability parameter. Inspired by Mutable Instruments Branches.
Implementations
Sourceimpl BernoulliGate
impl BernoulliGate