StereoOutput

Struct StereoOutput 

pub struct StereoOutput { /* private fields */ }
Stereo Output

The final output module that provides left and right audio outputs. Right input is normalled to left for mono compatibility.

Implementations

Source

impl StereoOutput

pub fn new() -> Self