pub struct ExternalInput { /* private fields */ }Available on crate feature
alloc only.Expand description
External input source - reads from an atomic value set by another thread
This module allows values from external sources (MIDI, OSC, GUI, etc.) to be brought into the patch graph in a lock-free manner.
Implementations
Sourceimpl ExternalInput
impl ExternalInput
Sourcepub fn new(value: Arc<AtomicF64>, kind: SignalKind) -> Self
pub fn new(value: Arc<AtomicF64>, kind: SignalKind) -> Self
Create a new external input with the specified signal kind
Sourcepub fn cv_bipolar(value: Arc<AtomicF64>) -> Self
pub fn cv_bipolar(value: Arc<AtomicF64>) -> Self
Create for bipolar CV