pub struct StereoOutput { /* private fields */ }Expand description
Stereo Output
The final output module that provides left and right audio outputs. Right input is normalled to left for mono compatibility.
Implementations
Sourceimpl StereoOutput
impl StereoOutput